==============
Certbot Django
==============

|  |license| |kit| |format| |downloads|

This is a combined plugin for the certbot ACME client and also a Django-app for proving ACME challenges.

**Full Documentation**: https://certbot-django.readthedocs.io


.. |license| image:: https://img.shields.io/pypi/l/certbot-django.svg
    :target: https://pypi.python.org/pypi/certbot-django
.. |kit| image:: https://badge.fury.io/py/certbot-django.svg
    :target: https://pypi.python.org/pypi/certbot-django
.. |format| image:: https://img.shields.io/pypi/format/certbot-django.svg
    :target: https://pypi.python.org/pypi/certbot-django
.. |downloads| image:: https://img.shields.io/pypi/dm/certbot-django.svg?maxAge=2592000
    :target: https://pypi.python.org/pypi/certbot-django
